@@ -71,7 +71,7 @@ class TriageVariable(object):
     def get_balance_table(self):  
         df = self.df
         proposed_variable = self.proposed
-        return df[["policy_gen", "age", "price_per_mile", proposed_variable]].groupby([proposed_variable]).describe() 
+        return df[["policy_gen", "policy_age", "odo miles", "age", "price_per_mile", proposed_variable]].groupby([proposed_variable]).describe() 
     
     
     def get_ols_model(self):
